Infrastructure Launcher
=======================

The launcher of the Dead-Hosts infrastructure and project.

Installation
------------

::

    $ pip3 install --user dead-hosts-launcher

Usage
-----


::

    usage: dead_hosts_launcher [-h] [-d] [-s] [-e] [-v]

    The launcher of the Dead-Hosts infrastructure.

    optional arguments:
        -h, --help     show this help message and exit
        -d, --debug    Activate the logging in verbose mode..
        -s, --save     Declare a test as 'to be continued'.
        -e, --end      Declare a test as completly finished and generate
                        `clean.list`.
        -v, --version  Show the version of and exit.

    Crafted with ♥ by Nissar Chababy (@funilrys)

License
-------

::

    MIT License

    Copyright (c) 2019 Dead Hosts
    Copyright (c) 2019 Nissar Chababy

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.
